@@ -1,15 +1,16 @@
 #  Copyright (c) 2022 Szymon Mikler
 
-from . import graph_algorithms, model_tools
-from .config import enable_module_call_optimization
+from . import functions_utility, graph_algorithms, model_tools
+from .config import optimize_module_calls
 from .functional_model import FunctionalModel
 from .symbolic_tensor import Input, SymbolicTensor
 
 __all__ = [
-    "enable_module_call_optimization",
     "FunctionalModel",
     "Input",
     "SymbolicTensor",
-    "model_tools",
+    "optimize_module_calls",
+    "functions_utility",
     "graph_algorithms",
+    "model_tools",
 ]
